<?php

namespace B2buy\Password\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Password\Http\Requests\SettingRequest;
use B2buy\Password\Interfaces\SettingRepositoryInterface;
use B2buy\Password\Models\Setting;
use B2buy\Password\Forms\Setting as Form;

/**
 * APIController  class for setting.
 */
class SettingAPIController extends BaseController
{

    /**
     * Initialize setting resource controller.
     *
     * @param type SettingRepositoryInterface $setting
     *
     * @return null
     */
    public function __construct(SettingRepositoryInterface $setting)
    {
        parent::__construct();
        $this->repository = $setting;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Password\Repositories\Criteria\SettingResourceCriteria::class);
    }

    /**
     * Display a list of setting.
     *
     * @return Response
     */
    public function index(SettingRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Password\Repositories\Presenter\SettingPresenter::class)
            ->paginate();
    }

    /**
     * Display setting.
     *
     * @param Request $request
     * @param Model   $setting
     *
     * @return Response
     */
    public function show(SettingRequest $request, Setting $setting)
    {
        return $setting->setPresenter(\B2buy\Password\Repositories\Presenter\SettingListPresenter::class);
        ;
    }

    /**
     * Create new setting.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SettingRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('password::setting.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('password/setting/' . $setting->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('password/setting');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the setting.
     *
     * @param Request $request
     * @param Model   $setting
     *
     * @return Response
     */
    public function update(SettingRequest $request, Setting $setting)
    {
        try {
            $data = $request->all();

            $setting->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('password::setting.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('password/setting/' . $setting->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('password/setting/' . $setting->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the setting.
     *
     * @param Model   $setting
     *
     * @return Response
     */
    public function destroy(SettingRequest $request, Setting $setting)
    {
        try {
            $setting->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('password::setting.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('password/setting/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('password/setting/' . $setting->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
