<?php

namespace B2buy\Password\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Password\Models\Setting;

class SettingPolicy
{

    /**
     * Determine if the given user can view the setting.
     *
     * @param UserPolicy $user
     * @param Setting $setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, Setting $setting)
    {
        if ($user->canDo('password.setting.view') && $user->isAdmin()) {
            return true;
        }

        return $setting->user_id == user_id() && $setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a setting.
     *
     * @param UserPolicy $user
     * @param Setting $setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('password.setting.create');
    }

    /**
     * Determine if the given user can update the given setting.
     *
     * @param UserPolicy $user
     * @param Setting $setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, Setting $setting)
    {
        if ($user->canDo('password.setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $setting->user_id == user_id() && $setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given setting.
     *
     * @param UserPolicy $user
     * @param Setting $setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Setting $setting)
    {
        return $setting->user_id == user_id() && $setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given setting.
     *
     * @param UserPolicy $user
     * @param Setting $setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Setting $setting)
    {
        if ($user->canDo('password.setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given setting.
     *
     * @param UserPolicy $user
     * @param Setting $setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Setting $setting)
    {
        if ($user->canDo('password.setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
